==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation>显示播放状态</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>音轨名显示格式 (例如：qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="33"/>
        <source>Print --nowplaying syntax</source>
        <translation>显示 --nowplaying 语法</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation>语法：</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation>%p - 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation>%a - 专辑</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation>%%aa - 专辑 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation>%t - 标题</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation>%n - 音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - 两位数音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation>%g - 流派</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation>%c - 备注</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation>%C - 作曲</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation>%D - 光盘编号</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation>%f - 文件名</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation>%F - 完整路径</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation>%y - 年代</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation>%l - 持续时间</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - 条件</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - 向上 n 级的目录名</translation>
    </message>
</context>
</TS>

==> qmmp-1.7.9.tar.bz2: qmmp-1.7.9/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation>显示播放状态</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>音轨名显示格式 (例如：qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="32"/>
        <source>Print --nowplaying syntax</source>
        <translation>显示 --nowplaying 语法</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation>语法：</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation>%p - 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation>%a - 专辑</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation>%%aa - 专辑 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation>%t - 标题</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation>%n - 音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - 两位数音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation>%g - 流派</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation>%c - 备注</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation>%C - 作曲</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation>%D - 光盘编号</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation>%f - 文件名</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation>%F - 完整路径</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation>%y - 年代</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation>%l - 持续时间</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation>%{bitrate} - bitrate</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation>%{samplerate} - 采样率</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation>%{channels} - 通道数</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation>%{samplesize} - 每样本比特数</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation>%{format} - 格式名</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation>%{decoder} - 解码器名</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation>%{filesize} - 文件大小</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - 条件</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - 向上 n 级的目录名</translation>
    </message>
</context>
</TS>
